#!/usr/bin/perl

# Please don't encrypt me!
# This space is left blank intentionally  
use Filter::CBC "Twofish","my secret key";
RandomIVga#3t%_fU	
-+>tc<0PMo1ѵd	.1A;zD`-	Yca¿_Î#4!ClN<Ux]$%gY/NA[hAn`R